; The CMD file.
;
; Two parts: 1. Command definition and  2. State entry
; (state entry is after the commands def section)
;
; 1. Command definition
; ---------------------
; Note: The commands are CASE-SENSITIVE, and so are the command names.
; The eight directions are:
;   B, DB, D, DF, F, UF, U, UB     (all CAPS)
;   corresponding to back, down-back, down, downforward, etc.
; The six buttons are:
;   a, b, c, x, y, z               (all lower case)
;   In default key config, abc are are the bottom, and xyz are on the
;   top row. For 2 button characters, we recommend you use a and b.
;   For 6 button characters, use abc for kicks and xyz for punches.
;
; Each [Command] section defines a command that you can use for
; state entry, as well as in the CNS file.
; The command section should look like:
;
;   [Command]
;   name = "some_name"
;   command = the_command
;   time = time (optional -- defaults to 15 if omitted)
;
; - some_name
;   A name to give that command. You'll use this name to refer to
;   that command in the state entry, as well as the CNS. It is case-
;   sensitive (QCB_a is NOT the same as Qcb_a or QCB_A).
;
; - command
;   list of buttons or directions, separated by commas.
;   Directions and buttons can be preceded by special characters:
;   slash (/) - means the key must be held down
;          egs. command = /D       ;hold the down direction
;               command = /F, a    ;hold fwd while you press a
;   tilde (~) - to detect key releases
;          egs. command = ~a       ;release the a button
;               command = ~D, F, a ;release down, press fwd, then a
;          If you want to detect "charge moves", you can specify
;          the time the key must be held down for (in game-ticks)
;          egs. command = ~30a     ;hold a for at least 30 ticks, then release
;               command = ~30
;   dollar ($) - Direction-only: detect as 4-way
;          egs. command = $D       ;will detect if D, DB or DF is held
;               command = $B       ;will detect if B, DB or UB is held
;   plus (+) - Buttons only: simultaneous press
;          egs. command = a+b      ;press a and b at the same time
;               command = x+y+z    ;press x, y and z at the same time
;   You can combine them:
;     eg. command = ~30$D, a+b     ;hold D, DB or DF for 30 ticks, release,
;                                  ;then press a and b together
;   It's recommended that for most "motion" commads, eg. quarter-circle-fwd,
;   you start off with a "release direction". This matches the way most
;   popular fighting games implement their engine.
;
; - time (optional)
;   Time allowed to do the command, given in game-ticks. Defaults to 15
;   if omitted
;
; If you have two or more commands with the same name, all of them will
; work. You can use it to allow multiple motions for the same move.
;
; Some common commands are given below. Delete, add, or modify as you wish.
;
;--------------------------------------------------------------------------
;-| Special Motions |------------------------------------------------------
;--------------------------------------------------------------------------
;
;====================
;Tenma Fukumetsu
;====================
[Command]
name = "temma"
command = ~F, D, B, F, b
time = 40

;====================
; Kage Bunshin
;====================
[Command]
name = "multiply_x"
command = ~F, B, DB, D, DF, F, x
time = 40

[Command]
name = "multiply_y"
command = ~F, B, DB, D, DF, F, y
time = 40

;====================
;Utsusemi Tenbu
;=====================
[Command]
name = "jig"
command = ~F, D, B, a+b+y
time = 30

[Command]
name = "jigCapcom"
command = ~F, D, B, y+c
time = 30

;====================
; Bakuenryu
;====================
[Command]
name = "baku_xy"
command = ~F, DF, D, DB, x+y
time = 25

[Command]
name = "baku_x"
command = ~F, DF, D, DB, x
time = 25

[Command]
name = "baku_y"
command = ~F, DF, D, DB, y
time = 25

[Command]
name = "baku_z"
command = ~F, DF, D, DB, z
time = 25

;====================
; Reppushuriken Kai
;====================
[Command]
name = "shuriken_xy"
command = ~B, DB, D, DF, x+y
time = 25

[Command]
name = "shuriken_x"
command = ~B, DB, D, DF, x
time = 25

[Command]
name = "shuriken_y"
command = ~B, DB, D, DF, y
time = 25

[Command]
name = "shuriken_z"
command = ~B, DB, D, DF, z
time = 25

;====================
; Mozu Otoshi 
;====================
[Command]
name = "mozu_ab"
command = ~F, D, DF, a+b
time = 30

[Command]
name = "mozu_a"
command = ~F, D, DF, a
time = 30

[Command]
name = "mozu_b"
command = ~F, D, DF, b
time = 30

[Command]
name = "mozu_c"
command = ~F, D, DF, c
time = 30

;--------------------------------------------------------------------------
;-| Double Tap |-----------------------------------------------------------
;--------------------------------------------------------------------------
;
[Command]
name = "DFDF"
command = DF, DF
time = 10

[Command]
name = "DBDB"
command = DB, DB
time = 10

[Command]
name = "FF";Required (do not remove)
command = F, F
time = 10

[Command]
name = "Fwd"
command = F
time = 10

[Command]
name = "BB";Required (do not remove)
command = B, B
time = 10

[Command]
name = "Bck"
command = B
time = 10

[Command]
name = "crouch"
command = D, D
time = 10

;--------------------------------------------------------------------------
;-| Taunts |---------------------------------------------------------------
;--------------------------------------------------------------------------
;
[Command]
name = "Taunt1"
command = x+a
time = 5

[Command]
name = "Taunt2"
command = y+b
time = 5

;--------------------------------------------------------------------------
;-| Dodges |---------------------------------------------------------------
;--------------------------------------------------------------------------
;
;Hop up
[Command]
name = "HopUp"
command = /F, y+a
time = 10

;Hop Away
[Command]
name = "HopAway"
command = y+a
time = 10

;-| 2/3 Button Combination |-----------------------------------------------
[Command]
name = "recovery";Required (do not remove)
command = a+x
time = 1

;Utsusemi Chizan (SNK layout)
[Command]
name = "yab"
command = a+b+y
time = 1

;Utsusemi Chizan (Capcom layout)
[Command]
name = "yc"
command = y+c
time = 1

[Command]
name = "ab"
command = a+b
time = 1

[Command]
name = "xy"
command = x+y
time = 1

;-| Dir + Button |---------------------------------------------------------
[Command]
name = "fwd_a"
command = /F,a
time = 1

[Command]
name = "fwd_b"
command = /F,b
time = 1

[Command]
name = "fwd_c"
command = /F,c
time = 1

[Command]
name = "fwd_xy"
command = /F,x+y
time = 1

[Command]
name = "fwd_x"
command = /F,x
time = 1

[Command]
name = "fwd_y"
command = /F,y
time = 1

[Command]
name = "fwd_z"
command = /F,z
time = 1

[Command]
name = "df_x"
command = /DF,x
time = 1

[Command]
name = "back_a"
command = /B,a
time = 1

[Command]
name = "back_b"
command = /B,b
time = 1

[Command]
name = "back_c"
command = /B,c
time = 1

[Command]
name = "down_a"
command = /$D,a
time = 1

[Command]
name = "down_b"
command = /$D,b
time = 1

[Command]
name = "down_c"
command = /$D,c
time = 1

[Command]
name = "down_xy"
command = /$D,x+y
time = 1

[Command]
name = "down_x"
command = /$D,x
time = 1

[Command]
name = "down_y"
command = /$D,y
time = 1

[Command]
name = "down_z"
command = /$D,z
time = 1

[Command]
name = "fwd_ab"
command = /F, a+b
time = 1

[Command]
name = "back_ab"
command = /B, a+b
time = 1

;-| Single Button |---------------------------------------------------------
[Command]
name = "a"
command = a
time = 1

[Command]
name = "b"
command = b
time = 1

[Command]
name = "c"
command = c
time = 1

[Command]
name = "x"
command = x
time = 1

[Command]
name = "y"
command = y
time = 1

[Command]
name = "z"
command = z
time = 1

;-| Hold Button |-----------------------------------------------------------
[Command]
name = "hold_x"
command = /x
time = 1

[Command]
name = "hold_y"
command = /y
time = 1

[Command]
name = "hold_a"
command = /a
time = 1

[Command]
name = "hold_b"
command = /b
time = 1

;-| Hold Dir |--------------------------------------------------------------
[Command]
name = "holdfwd";Required (do not remove)
command = /$F
time = 1

[Command]
name = "holdback";Required (do not remove)
command = /$B
time = 1

[Command]
name = "holdup";Required (do not remove)
command = /$U
time = 1

[Command]
name = "holddown";Required (do not remove)
command = /$D
time = 1

;---------------------------------------------------------------------------
; 2. State entry
; --------------
; This is where you define what commands bring you to what states.
;
; Each state entry block looks like:
;   [State -1]                  ;Don't change this
;   type = ChangeState          ;Don't change this
;   value = new_state_number
;   trigger1 = command = "command_name"
;   . . .  (any additional triggers)
;
; - new_state_number is the number of the state to change to
; - command_name is the name of the command (from the section above)
; - Useful triggers to know:
;   - statetype
;       S, C or A : current state-type of player (stand, crouch, )
;   - ctrl
;       0 or 1 : 1 if player has control. Unless "interrupting" another
;                move, you'll want ctrl = 1
;   - stateno
;       number of state player is in - useful for "move interrupts"
;   - movecontact
;       0 or 1 : 1 if player's last attack touched the opponent
;                useful for "move interrupts"
;
; Note: The order of state entry is important.
;   State entry with a certain command must come before another state
;   entry with a command that is the subset of the first.  
;   For example, command "fwd_a" must be listed before "a", and
;   "fwd_ab" should come before both of the others.
;
; For reference on triggers, see CNS documentation.
;
; Just for your information (skip if you're not interested):
; This part is an extension of the CNS. "State -1" is a special state
; that is executed once every game-tick, regardless of what other state
; you are in. 
; Don't remove the following line. It's required by the CMD standard.
[Statedef -1]
;===========================================================================
;Triangle Jump Right
[State -1]
type = ChangeState
value = 900
triggerall = statetype = A
triggerall = Pos Y < -50
trigger1 = command = "Fwd"
trigger1 = backedgebodydist <= 2

;---------------------------------------------------------------------------
;Triangle Jump Left
[State -1]
type = ChangeState
value = 905
triggerall = statetype = A
triggerall = Pos Y < -50
trigger1 = command = "Bck"
trigger1 = frontedgebodydist <= 2

;-----------------------------------------------------------------------
;Taunt1
[State -1]
type = ChangeState
value = 578
triggerall = command = "Taunt1"
triggerall = statetype = S
triggerall = p2bodydist X > 90
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Utsusemi Tenbu (SNK Layout)
[State -1]
type = ChangeState
value = 1200
triggerall = command = "jig"
triggerall = statetype = S
trigger1 = ctrl = 1  

;-----------------------------------------------------------------------
;Hop Up
[State -1]
type = ChangeState
value = 475
triggerall = command = "HopUp"
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 578 ; cancel taunt 1
trigger3 = stateno = 579 ; cancel taunt 2

;-----------------------------------------------------------------------
;Hop Away
[State -1]
type = ChangeState
value = 470
triggerall = command = "HopAway"
triggerall = statetype = S
trigger1 = ctrl = 1
trigger2 = stateno = 578 ; cancel taunt 1
trigger3 = stateno = 579 ; cancel taunt 2

;---------------------------------------------------------------------------
;RunFwd
[State -1]
type = ChangeState
value = 100
trigger1 = command = "FF"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;RunBack
[State -1]
type = ChangeState
value = 105
trigger1 = command = "BB"
trigger1 = statetype = S
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Tenma Fukumetsu (DM)
[State -1]
type = ChangeState
value = 3000
triggerall = command = "temma"
triggerall = statetype != A
triggerall = power >= 1000
trigger1 = statetype = S
trigger1 = ctrl = 1  
trigger2 = stateno = 210
trigger2 = movecontact = 1
trigger3 = stateno = 215
trigger3 = movecontact = 1

;---------------------------------------------------------------------------
;Mozu Otoshi (AB) running
[State -1]
type = ChangeState
value = 2700
triggerall = command = "mozu_ab"
triggerall = statetype != A
triggerall = p2bodydist X < 18
trigger1 = stateno = 100
trigger2 = stateno = 101

;---------------------------------------------------------------------------
;Mozu Otoshi (A)
[State -1]
type = ChangeState
value = 2500
triggerall = command = "mozu_a"
triggerall = statetype != A
triggerall = p2bodydist X < 18
trigger1 = stateno = 100
trigger2 = stateno = 101

;---------------------------------------------------------------------------
;Mozu Otoshi (B)
[State -1]
type = ChangeState
value = 2600
triggerall = command = "mozu_b"
triggerall = statetype != A
triggerall = p2bodydist X < 18
trigger1 = stateno = 100
trigger2 = stateno = 101

;---------------------------------------------------------------------------
;Mozu Otoshi (AB)
[State -1]
type = ChangeState
value = 2700
triggerall = command = "mozu_c"
triggerall = statetype != A
triggerall = p2bodydist X < 18
trigger1 = stateno = 100
trigger2 = stateno = 101

;---------------------------------------------------------------------------
;Mozu Otoshi (AB)
[State -1]
type = ChangeState
value = 1700
triggerall = command = "mozu_ab"
triggerall = statetype != A
triggerall = p2bodydist X < 9
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Mozu Otoshi (A)
[State -1]
type = ChangeState
value = 1500
triggerall = command = "mozu_a"
triggerall = statetype != A
triggerall = p2bodydist X < 9
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Mozu Otoshi (B)
[State -1]
type = ChangeState
value = 1600
triggerall = command = "mozu_b"
triggerall = statetype != A
triggerall = p2bodydist X < 9
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Mozu Otoshi (AB)
[State -1]
type = ChangeState
value = 1700
triggerall = command = "mozu_c"
triggerall = statetype != A
triggerall = p2bodydist X < 9
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Reppushuriken Kai (AB)
[State -1]
type = ChangeState
value = 1320
triggerall = command = "shuriken_xy"
triggerall = statetype = A
trigger1 = ctrl = 1  

;-----------------------------------------------------------------------
;Reppushuriken Kai (A)
[State -1]
type = ChangeState
value = 1300
triggerall = command = "shuriken_x"
triggerall = statetype = A
trigger1 = ctrl = 1  

;-----------------------------------------------------------------------
;Reppushuriken Kai (B)
[State -1]
type = ChangeState
value = 1310
triggerall = command = "shuriken_y"
triggerall = statetype = A
trigger1 = ctrl = 1  

;-----------------------------------------------------------------------
;Reppushuriken Kai (C)
[State -1]
type = ChangeState
value = 1320
triggerall = command = "shuriken_z"
triggerall = statetype = A
trigger1 = ctrl = 1  

;-----------------------------------------------------------------------
;Utsusemi Chizan
[State -1]
type = ChangeState
value = 1100
triggerall = command = "yab"
triggerall = statetype != A
triggerall = Time = [0, 15]
trigger1 = stateno = 5000
trigger2 = stateno = 5001
trigger3 = stateno = 5002
trigger4 = stateno = 5010
trigger5 = stateno = 5011
trigger6 = stateno = 5012
trigger7 = stateno = 5020
trigger8 = stateno = 5021
trigger9 = stateno = 5022
trigger10 = stateno = 5105

;-----------------------------------------------------------------------
;Utsusemi Chizan
[State -1]
type = ChangeState
value = 1100
triggerall = command = "yc"
triggerall = statetype != A
triggerall = Time = [0, 15]
trigger1 = stateno = 5000
trigger2 = stateno = 5001
trigger3 = stateno = 5002
trigger4 = stateno = 5010
trigger5 = stateno = 5011
trigger6 = stateno = 5012
trigger7 = stateno = 5020
trigger8 = stateno = 5021
trigger9 = stateno = 5022
trigger10 = stateno = 5105

;-----------------------------------------------------------------------
;Utsusemi Tenbu (Capcom Layout)
[State -1]
type = ChangeState
value = 1200
triggerall = command = "jigCapcom"
triggerall = statetype = S
trigger1 = ctrl = 1  

;-----------------------------------------------------------------------
;Bakuenryu (AB)
[State -1]
type = ChangeState
value = 1020
triggerall = command = "baku_xy"
triggerall = statetype = S
triggerall = numproj = 0
trigger1 = stateno = 210
trigger1 = movecontact = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = ctrl = 1  

;-----------------------------------------------------------------------
;Bakuenryu (A)
[State -1]
type = ChangeState
value = 1000
triggerall = command = "baku_x"
triggerall = statetype = S
triggerall = numproj = 0
trigger1 = stateno = 210
trigger1 = movecontact = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = ctrl = 1  

;-----------------------------------------------------------------------
;Bakuenryu (B)
[State -1]
type = ChangeState
value = 1010
triggerall = command = "baku_y"
triggerall = statetype = S
triggerall = numproj = 0
trigger1 = stateno = 210
trigger1 = movecontact = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = ctrl = 1  

;-----------------------------------------------------------------------
;Bakuenryu (AB)
[State -1]
type = ChangeState
value = 1020
triggerall = command = "baku_z"
triggerall = statetype = S
triggerall = numproj = 0
trigger1 = stateno = 210
trigger1 = movecontact = 1
trigger2 = stateno = 215
trigger2 = movecontact = 1
trigger3 = ctrl = 1  

;---------------------------------------------------------------------------
;Lie Down
[State -1]
type = ChangeState
value = 479
triggerall = statetype != A
triggerall = command = "crouch"
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Throw (B/AB)
[State -1]
type = ChangeState
value = 840
triggerall = statetype != A
triggerall = p2bodydist X < 9
trigger1 = command = "fwd_y"
trigger1 = ctrl = 1
trigger2 = command = "fwd_z"
trigger2 = ctrl = 1
trigger3 = command = "fwd_xy"
trigger3 = ctrl = 1

;---------------------------------------------------------------------------
;Air Throw (B)
[State -1]
type = ChangeState
value = 840
triggerall = statetype = A
triggerall = p2statetype = A
triggerall = p2bodydist X < 9
triggerall = p2bodydist Y > -22
triggerall = p2bodydist Y < 22
triggerall = p2movetype != H
trigger1 = command = "down_y"
trigger1 = ctrl = 1
trigger2 = command = "down_z"
trigger2 = ctrl = 1
trigger3 = command = "down_xy"
trigger3 = ctrl = 1


;-----------------------------------------------------------------------
;Stand_AB [sword] (Close)
[State -1]
type = ChangeState
value = 225
triggerall = command = "xy";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_AB [sword] (Far)
[State -1]
type = ChangeState
value = 220
triggerall = command = "xy";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_CD [kick] (Close)
[State -1]
type = ChangeState
value = 255
triggerall = command = "ab";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_CD [kick] (Far)
[State -1]
type = ChangeState
value = 250
triggerall = command = "ab";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_A [sword] (Close)
[State -1]
type = ChangeState
value = 205
triggerall = command = "x";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_A [sword] (Far)
[State -1]
type = ChangeState
value = 200
triggerall = command = "x";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_B [sword] (Close)
[State -1]
type = ChangeState
value = 215
triggerall = command = "y";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_B [sword] (Far)
[State -1]
type = ChangeState
value = 210
triggerall = command = "y";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_AB [sword] (Close)
[State -1]
type = ChangeState
value = 225
triggerall = command = "z";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_AB [sword] (Far)
[State -1]
type = ChangeState
value = 220
triggerall = command = "z";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_C [kick] (Close)
[State -1]
type = ChangeState
value = 235
triggerall = command = "a";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_C [Kick] (Far)
[State -1]
type = ChangeState
value = 230
triggerall = command = "a";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_D [kick] (Close)
[State -1]
type = ChangeState
value = 245
triggerall = command = "b";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_D [kick] (Far)
[State -1]
type = ChangeState
value = 240
triggerall = command = "b";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_CD [kick] (Close)
[State -1]
type = ChangeState
value = 255
triggerall = command = "c";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Stand_CD [kick] (Far)
[State -1]
type = ChangeState
value = 250
triggerall = command = "c";Place name of command here
triggerall = command != "holddown";Standing moves should have this line
trigger1 = statetype = S
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch AB [Sword]
[State -1]
type = ChangeState
value = 420
triggerall = command = "xy";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch CD [Kick] (close)  // THIS KICK HITS TWICE
[State -1]
type = ChangeState
value = 455
triggerall = command = "ab";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch CD [Kick] (far)
[State -1]
type = ChangeState
value = 450
triggerall = command = "ab";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch A [Sword]
[State -1]
type = ChangeState
value = 400
triggerall = command = "x";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch B [Sword]
[State -1]
type = ChangeState
value = 410
triggerall = command = "y";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch AB [Sword]
[State -1]
type = ChangeState
value = 420
triggerall = command = "z";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch C [Kick]
[State -1]
type = ChangeState
value = 430
triggerall = command = "a";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch D [Kick]
[State -1]
type = ChangeState
value = 440
triggerall = command = "b";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch CD [Kick] (close)
[State -1]
type = ChangeState
value = 455
triggerall = command = "c";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
triggerall = p2bodydist X < 9
trigger1 = statetype = C
trigger1 = ctrl = 1

;-----------------------------------------------------------------------
;Crouch CD [Kick] (far)
[State -1]
type = ChangeState
value = 450
triggerall = command = "c";Place name of command here
triggerall = command = "holddown";Crouching moves should have this line
trigger1 = statetype = C
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping AB [Sword]
[State -1]
type = ChangeState
value = 620
trigger1 = command = "xy"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping CD [Kick]
[State -1]
type = ChangeState
value = 650
trigger1 = command = "ab"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping A [Sword]
[State -1]
type = ChangeState
value = 600
trigger1 = command = "x"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping B [Sword]
[State -1]
type = ChangeState
value = 610
trigger1 = command = "y"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping AB [Sword]
[State -1]
type = ChangeState
value = 620
trigger1 = command = "z"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping C [Kick]
[State -1]
type = ChangeState
value = 630
trigger1 = command = "a"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping D [Kick]
[State -1]
type = ChangeState
value = 640
trigger1 = command = "b"
trigger1 = statetype = A
trigger1 = ctrl = 1

;---------------------------------------------------------------------------
;Jumping CD [Kick]
[State -1]
type = ChangeState
value = 650
trigger1 = command = "c"
trigger1 = statetype = A
trigger1 = ctrl = 1
